@@ -37,6 +37,7 @@ def register():
         OperationalSector,
         Family,
         FamilyMember,
+        DomiciliaryUnit,
         MedicamentCategory,
         Medicament,
         PathologyCategory,
@@ -46,8 +47,11 @@ def register():
         ProcedureCode,
         InsurancePlan,
         Insurance,
+        AlternativePersonID,
         PartyPatient,
         PartyAddress,
+        ProductCategory,
+        ProductTemplate,
         Product,
         GnuHealthSequences,
         PatientData,
@@ -55,7 +59,6 @@ def register():
         Appointment,
         AppointmentReport,
         OpenAppointmentReportStart,
-        MedicationTemplate,
         PatientMedication,
         PatientVaccination,
         PatientPrescriptionOrder,
