@@ -21,6 +21,7 @@
 
 from trytond.pool import Pool
 from .health_inpatient import *
+from wizard import *
 
 
 def register():
@@ -29,10 +30,17 @@ def register():
         DietTherapeutic,
         DietBelief,
         InpatientRegistration,
+        BedTransfer,
         Appointment,
         PatientData,
         InpatientMedication,
         InpatientMedicationAdminTimes,
         InpatientMedicationLog,
         InpatientDiet,
+        CreateBedTransferInit,
         module='health_inpatient', type_='model')
+    
+    Pool.register(
+        CreateBedTransfer,
+        module='health_inpatient', type_='wizard')
+
