@@ -70,6 +70,10 @@ class TestType(ModelSQL, ModelView):
             ('code_uniq', 'unique(name)', 'The Lab Test code must be unique'),
         ]
 
+    @classmethod
+    def check_xml_record(cls, records, values):
+        return True
+
 
 class Lab(ModelSQL, ModelView):
     'Lab Test'
@@ -108,17 +112,18 @@ class Lab(ModelSQL, ModelView):
         return datetime.now()
 
     @classmethod
-    def create(cls, values):
+    def create(cls, vlist):
         Sequence = Pool().get('ir.sequence')
         Config = Pool().get('gnuhealth.sequences')
 
-        values = values.copy()
-        if not values.get('name'):
-            config = Config(1)
-            values['name'] = Sequence.get_id(
-                config.lab_sequence.id)
+        vlist = [x.copy() for x in vlist]
+        for values in vlist:
+            if not values.get('name'):
+                config = Config(1)
+                values['name'] = Sequence.get_id(
+                    config.lab_sequence.id)
 
-        return super(Lab, cls).create(values)
+        return super(Lab, cls).create(vlist)
 
 
 class GnuHealthLabTestUnits(ModelSQL, ModelView):
@@ -135,6 +140,10 @@ class GnuHealthLabTestUnits(ModelSQL, ModelView):
             ('name_uniq', 'unique(name)', 'The Unit name must be unique'),
         ]
 
+    @classmethod
+    def check_xml_record(cls, records, values):
+        return True
+
 
 class GnuHealthTestCritearea(ModelSQL, ModelView):
     'Lab Test Critearea'
@@ -180,6 +189,10 @@ class GnuHealthTestCritearea(ModelSQL, ModelView):
             return True
         return False
 
+    @classmethod
+    def check_xml_record(cls, records, values):
+        return True
+
 
 class GnuHealthPatientLabTest(ModelSQL, ModelView):
     'Patient Lab Test'
@@ -233,14 +246,25 @@ class GnuHealthPatientLabTest(ModelSQL, ModelView):
             return False
 
     @classmethod
-    def create(cls, values):
+    def create(cls, vlist):
         Sequence = Pool().get('ir.sequence')
         Config = Pool().get('gnuhealth.sequences')
 
-        values = values.copy()
-        if not values.get('request'):
-            config = Config(1)
-            values['request'] = Sequence.get_id(
-                config.lab_request_sequence.id)
+        vlist = [x.copy() for x in vlist]
+        for values in vlist:
+            if not values.get('request'):
+                config = Config(1)
+                values['request'] = Sequence.get_id(
+                    config.lab_request_sequence.id)
 
-        return super(GnuHealthPatientLabTest, cls).create(values)
+        return super(GnuHealthPatientLabTest, cls).create(vlist)
+
+    @classmethod
+    def copy(cls, tests, default=None):
+        if default is None:
+            default = {}
+        default = default.copy()
+        default['request'] = None
+        default['date'] = cls.default_date()
+        return super(GnuHealthPatientLabTest, cls).copy(tests,
+            default=default)
