@@ -2,7 +2,7 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2012  Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2008-2013  Luis Falcon <lfalcon@gnusolidario.org>
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -19,5 +19,18 @@
 #
 ##############################################################################
 
-from health_services import * 
-from wizard import * 
+from trytond.pool import Pool
+from .health_services import *
+from wizard import *
+
+
+def register():
+    Pool.register(
+        GnuHealthSequences,
+        HealthService,
+        HealthServiceLine,
+        CreateServiceInvoiceInit,
+        module='health_services', type_='model')
+    Pool.register(
+        CreateServiceInvoice,
+        module='health_services', type_='wizard')
