@@ -19,21 +19,19 @@
 #
 ##############################################################################
 from trytond.model import ModelView, ModelSQL, fields
+from trytond.transaction import Transaction
+from trytond.backend import TableHandler
 
-__all__ = ['MedicalPatient']
+__all__ = ['Party','GnuHealthPatient']
 
-class MedicalPatient(ModelSQL, ModelView):
-    __name__ = 'gnuhealth.patient'
 
-    ses = fields.Selection([
-        ('0', 'Lower'),
-        ('1', 'Lower-middle'),
-        ('2', 'Middle'),
-        ('3', 'Middle-upper'),
-        ('4', 'Higher'),
-        ], 'Socioeconomics', help="SES - Socioeconomic Status", sort=False)
+class Party (ModelSQL, ModelView):
+    __name__ = 'party.party'
+
+    occupation = fields.Many2One('gnuhealth.occupation', 'Occupation')
 
     education = fields.Selection([
+        (None, ''),
         ('0', 'None'),
         ('1', 'Incomplete Primary School'),
         ('2', 'Primary School'),
@@ -42,25 +40,33 @@ class MedicalPatient(ModelSQL, ModelView):
         ('5', 'University'),
         ], 'Education Level', help="Education Level", sort=False)
 
-    housing = fields.Selection([
-        ('0', 'Shanty, deficient sanitary conditions'),
-        ('1', 'Small, crowded but with good sanitary conditions'),
-        ('2', 'Comfortable and good sanitary conditions'),
-        ('3', 'Roomy and excellent sanitary conditions'),
-        ('4', 'Luxury and excellent sanitary conditions'),
-        ], 'Housing conditions', help="Housing and sanitary living conditions", sort=False)
+
+class GnuHealthPatient(ModelSQL, ModelView):
+    __name__ = 'gnuhealth.patient'
+
+    def get_patient_occupation(self, name):
+        if (self.name.occupation):
+            return self.name.occupation.id
+
+    def get_patient_education(self, name):
+        return self.name.education
+
+    def get_patient_housing(self, name):
+        if (self.name.du):
+            return self.name.du.housing
+
+    ses = fields.Selection([
+        (None, ''),
+        ('0', 'Lower'),
+        ('1', 'Lower-middle'),
+        ('2', 'Middle'),
+        ('3', 'Middle-upper'),
+        ('4', 'Higher'),
+        ], 'Socioeconomics', help="SES - Socioeconomic Status", sort=False)
 
     hostile_area = fields.Boolean('Hostile Area',
         help="Check if patient lives in a zone of high hostility (eg, war)")
 
-    sewers = fields.Boolean('Sanitary Sewers')
-    water = fields.Boolean('Running Water')
-    trash = fields.Boolean('Trash recollection')
-    electricity = fields.Boolean('Electrical supply')
-    gas = fields.Boolean('Gas supply')
-    telephone = fields.Boolean('Telephone')
-    television = fields.Boolean('Television')
-    internet = fields.Boolean('Internet')
     single_parent = fields.Boolean('Single parent family')
     domestic_violence = fields.Boolean('Domestic violence')
     working_children = fields.Boolean('Working children')
@@ -77,6 +83,7 @@ class MedicalPatient(ModelSQL, ModelView):
     ses_notes = fields.Text('Extra info')
 
     fam_apgar_help = fields.Selection([
+        (None, ''),
         ('0', 'None'),
         ('1', 'Moderately'),
         ('2', 'Very much'),
@@ -85,6 +92,7 @@ class MedicalPatient(ModelSQL, ModelView):
         "the family when there is a problem ?", sort=False)
 
     fam_apgar_discussion = fields.Selection([
+        (None, ''),
         ('0', 'None'),
         ('1', 'Moderately'),
         ('2', 'Very much'),
@@ -93,6 +101,7 @@ class MedicalPatient(ModelSQL, ModelView):
         "problems as family ?", sort=False)
 
     fam_apgar_decisions = fields.Selection([
+        (None, ''),
         ('0', 'None'),
         ('1', 'Moderately'),
         ('2', 'Very much'),
@@ -101,6 +110,7 @@ class MedicalPatient(ModelSQL, ModelView):
         "decisions as a group ?", sort=False)
 
     fam_apgar_timesharing = fields.Selection([
+        (None, ''),
         ('0', 'None'),
         ('1', 'Moderately'),
         ('2', 'Very much'),
@@ -109,6 +119,7 @@ class MedicalPatient(ModelSQL, ModelView):
         "spend together ?", sort=False)
 
     fam_apgar_affection = fields.Selection([
+        (None, ''),
         ('0', 'None'),
         ('1', 'Moderately'),
         ('2', 'Very much'),
@@ -125,12 +136,37 @@ class MedicalPatient(ModelSQL, ModelView):
         'fam_apgar_discussion', 'fam_apgar_decisions', 'fam_apgar_affection'])
 
     income = fields.Selection([
+        (None, ''),
         ('h', 'High'),
         ('m', 'Medium / Average'),
         ('l', 'Low'),
         ], 'Income', sort=False)
 
-    occupation = fields.Many2One('gnuhealth.occupation', 'Occupation')
+
+    # GnuHealth 2.0 . Occupation and Education are now functional fields.
+    # Retrives the information from the party model.
+    occupation = fields.Function(fields.Many2One('gnuhealth.occupation','Occupation'), 'get_patient_occupation')
+
+    education = fields.Function(fields.Selection([
+        (None, ''),
+        ('0', 'None'),
+        ('1', 'Incomplete Primary School'),
+        ('2', 'Primary School'),
+        ('3', 'Incomplete Secondary School'),
+        ('4', 'Secondary School'),
+        ('5', 'University'),
+        ], 'Education Level', help="Education Level", sort=False), 'get_patient_education')
+
+
+    housing = fields.Function(fields.Selection([
+        (None, ''),
+        ('0', 'Shanty, deficient sanitary conditions'),
+        ('1', 'Small, crowded but with good sanitary conditions'),
+        ('2', 'Comfortable and good sanitary conditions'),
+        ('3', 'Roomy and excellent sanitary conditions'),
+        ('4', 'Luxury and excellent sanitary conditions'),
+        ], 'Housing conditions', help="Housing and sanitary living conditions", sort=False), 'get_patient_housing')
+
     works_at_home = fields.Boolean('Works at home',
         help="Check if the patient works at his / her house")
     hours_outside = fields.Integer('Hours outside home',
@@ -175,3 +211,56 @@ class MedicalPatient(ModelSQL, ModelView):
             fam_apgar_affection)
 
         return total
+
+    @classmethod
+    # Update to version 2.0
+    def __register__(cls, module_name):
+        super(GnuHealthPatient, cls).__register__(module_name)
+
+        cursor = Transaction().cursor
+        table = TableHandler(cursor, cls, module_name)
+        # Move occupation from patient to party
+
+        if table.column_exist('occupation'):
+            cursor.execute ('UPDATE PARTY_PARTY '
+                'SET OCCUPATION = GNUHEALTH_PATIENT.OCCUPATION '
+                'FROM GNUHEALTH_PATIENT '
+                'WHERE GNUHEALTH_PATIENT.NAME = PARTY_PARTY.ID')
+
+            table.drop_column('occupation')
+
+        # Move education from patient to party
+
+        if table.column_exist('education'):
+            cursor.execute ('UPDATE PARTY_PARTY '
+                'SET EDUCATION = GNUHEALTH_PATIENT.EDUCATION '
+                'FROM GNUHEALTH_PATIENT '
+                'WHERE GNUHEALTH_PATIENT.NAME = PARTY_PARTY.ID')
+
+            table.drop_column('education')
+
+        # The following indicators are now part of the Domiciliary Unit
+
+        if table.column_exist('sewers'):
+            table.drop_column ('sewers')
+
+        if table.column_exist('water'):
+            table.drop_column ('water')
+
+        if table.column_exist('trash'):
+            table.drop_column ('trash')
+
+        if table.column_exist('electricity'):
+            table.drop_column ('electricity')
+
+        if table.column_exist('gas'):
+            table.drop_column ('gas')
+
+        if table.column_exist('telephone'):
+            table.drop_column ('telephone')
+
+        if table.column_exist('internet'):
+            table.drop_column ('internet')
+
+        if table.column_exist('housing'):
+            table.drop_column ('housing')
